@@ -119,7 +119,7 @@ sub new {
 
     # set the lexer to Perl 5
     $self->SetLexer(wxSTC_LEX_PERL);
-    $self->SetStyleBits(7);
+    $self->SetStyleBits($self->GetStyleBitsNeeded);
 
     my @keywords = qw(
       NULL __FILE__ __LINE__ __PACKAGE__ __DATA__ __END__ AUTOLOAD
@@ -163,6 +163,18 @@ sub new {
     }
     $self->SetFocus;
 
+    Wx::Event::EVT_STC_INDICATOR_CLICK( $self, $self, sub {
+        print "EVT_STC_INDICATOR_CLICK triggered\n";
+    } );
+
+    Wx::Event::EVT_STC_INDICATOR_RELEASE( $self, $self, sub {
+        print "EVT_STC_INDICATOR_RELEASE triggered\n";
+    } );
+
+    $self->IndicatorSetForeground( 0, Wx::Colour->new("red") );
+    $self->SetIndicatorCurrent(0);
+    $self->IndicatorFillRange(0, 20);
+    
     return $self;
 }
 
